@@ -25,6 +25,24 @@ class TestMessage(unittest.TestCase):
         self.assertEqual(katcp.Message.reply("foo", "fail", "ok").reply_ok(), False)
         self.assertEqual(katcp.Message.request("foo", "ok").reply_ok(), False)
 
+    def test_request(self):
+        """Test request method."""
+        self.assertEqual(str(katcp.Message.request("foo")), "?foo")
+        self.assertEqual(str(katcp.Message.request("foo", mid=123)), "?foo[123]")
+        self.assertEqual(str(katcp.Message.request("foo", "a", "b", mid=123)), "?foo[123] a b")
+
+    def test_reply(self):
+        """Test reply method."""
+        self.assertEqual(str(katcp.Message.reply("foo")), "!foo")
+        self.assertEqual(str(katcp.Message.reply("foo", mid=123)), "!foo[123]")
+        self.assertEqual(str(katcp.Message.reply("foo", "a", "b", mid=123)), "!foo[123] a b")
+
+    def test_inform(self):
+        """Test inform method."""
+        self.assertEqual(str(katcp.Message.inform("foo")), "#foo")
+        self.assertEqual(str(katcp.Message.inform("foo", mid=123)), "#foo[123]")
+        self.assertEqual(str(katcp.Message.inform("foo", "a", "b", mid=123)), "#foo[123] a b")
+
 
 class TestMessageParser(unittest.TestCase):
     def setUp(self):
@@ -102,6 +120,20 @@ class TestMessageParser(unittest.TestCase):
         m = self.p.parse("!baz \fa\fb\f")
         self.assertEqual(m.arguments, ["\fa\fb\f"])
 
+    def test_message_ids(self):
+        """Test that messages with message ids are parsed as expected."""
+        m = self.p.parse("?bar[123]")
+        self.assertEqual(m.mtype, m.REQUEST)
+        self.assertEqual(m.name, "bar")
+        self.assertEqual(m.arguments, [])
+        self.assertEqual(m.mid, "123")
+
+        m = self.p.parse("!baz[1234] a b c")
+        self.assertEqual(m.mtype, m.REPLY)
+        self.assertEqual(m.name, "baz")
+        self.assertEqual(m.arguments, ["a", "b", "c"])
+        self.assertEqual(m.mid, "1234")
+
 
 class TestSensor(unittest.TestCase):
     def test_int_sensor(self):
